==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/ast.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "Compartiendo",
    "External Storage" : "Almacenamientu esternu",
    "Cron" : "Cron",
    "Log" : "Rexistru",
    "Updates" : "Anovamientos",
    "Couldn't remove app." : "Nun pudo desaniciase l'aplicación.",
    "Language changed" : "Camudóse la llingua",
    "Invalid request" : "Solicitú inválida",
    "Authentication error" : "Fallu d'autenticación",
    "Admins can't remove themself from the admin group" : "Los alministradores nun puen desaniciase a ellos mesmos del grupu d'alministrador",
    "Unable to add user to group %s" : "Nun pudo amestase l'usuariu al grupu %s",
    "Unable to remove user from group %s" : "Nun pudo desaniciase al usuariu del grupu %s",
    "Couldn't update app." : "Nun pudo anovase l'aplicación.",
    "Wrong password" : "Contraseña incorreuta",
    "No user supplied" : "Nun s'especificó un usuariu",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Facilita una contraseña de recuperación d'alministrador, sinón podríen perdese tolos datos d'usuariu",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación d'alministrador incorreuta. Comprueba la contraseña ya inténtalo dempués.",
    "Unable to change password" : "Nun pudo camudase la contraseña",
    "Enabled" : "Habilitar",
    "Not enabled" : "Desactiváu",
    "Saved" : "Guardáu",
    "test email settings" : "probar configuración de corréu",
    "Email sent" : "Corréu-e unviáu",
    "You need to set your user email before being able to send test emails." : "Tienes de configurar la direición de corréu-e enantes de poder unviar mensaxes de prueba.",
    "Email saved" : "Corréu-e guardáu",
    "Your full name has been changed." : "Camudóse'l nome completu.",
    "Unable to change full name" : "Nun pue camudase'l nome completu",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "¿De xuru que quies amestar \"{domain}\" como dominiu de confianza?",
    "Add trusted domain" : "Amestar dominiu de confianza",
    "Sending..." : "Unviando...",
    "All" : "Toos",
    "Please wait...." : "Espera, por favor....",
    "Error while disabling app" : "Fallu mientres se desactivaba l'aplicación",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Error while enabling app" : "Fallu mientres s'activaba l'aplicación",
    "Updating...." : "Anovando....",
    "Error while updating app" : "Fallu mientres s'anovaba l'aplicación",
    "Updated" : "Anováu",
    "Uninstalling ...." : "Desinstalando ...",
    "Error while uninstalling app" : "Fallu mientres se desinstalaba l'aplicación",
    "Uninstall" : "Desinstalar",
    "Valid until {date}" : "Válidu fasta {date}",
    "Delete" : "Desaniciar",
    "Select a profile picture" : "Esbillar una imaxe de perfil",
    "Very weak password" : "Contraseña mui feble",
    "Weak password" : "Contraseña feble",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña bona",
    "Strong password" : "Contraseña mui bona",
    "Groups" : "Grupos",
    "Unable to delete {objName}" : "Nun pue desaniciase {objName}",
    "A valid group name must be provided" : "Hai d'escribir un nome de grupu válidu",
    "deleted {groupName}" : "desaniciáu {groupName}",
    "undo" : "desfacer",
    "no group" : "Ensín grupu",
    "never" : "enxamás",
    "deleted {userName}" : "desaniciáu {userName}",
    "add group" : "amestar Grupu",
    "A valid username must be provided" : "Tien d'apurrise un nome d'usuariu válidu",
    "A valid password must be provided" : "Tien d'apurrise una contraseña válida",
    "__language_name__" : "Asturianu",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Too (Información, Avisos, Fallos, debug y problemes fatales)",
    "Info, warnings, errors and fatal issues" : "Información, Avisos, Fallos y problemes fatales",
    "Warnings, errors and fatal issues" : "Avisos, fallos y problemes fatales",
    "Errors and fatal issues" : "Fallos y problemes fatales",
    "Fatal issues only" : "Namái problemes fatales",
    "None" : "Dengún",
    "Login" : "Entamar sesión",
    "Plain" : "Planu",
    "NT LAN Manager" : "Xestor de NT LAN",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ta aparentemente configuráu pa desaniciar bloques de documentos en llinia. Esto va facer que delles aplicaciones principales nun tean accesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dablemente esto seya culpa d'un caché o acelerador, como por exemplu Zend OPcache o eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Nun s'atopó'l módulu PHP 'fileinfo'. Encamentámoste qu'habilites esti módulu pa obtener meyores resultaos cola deteición de tribes MIME.",
    "System locale can not be set to a one which supports UTF-8." : "Nun se pue escoyer una configuración rexonal que sofite UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Esto significa que pue haber problemes con ciertos caráuteres nos nomes de los ficheros.",
    "Allow apps to use the Share API" : "Permitir a les aplicaciones usar la API de Compartición",
    "Allow users to share via link" : "Permitir a los usuarios compartir vía enllaz",
    "Enforce password protection" : "Ameyora la proteición por contraseña.",
    "Allow public uploads" : "Permitir xubes públiques",
    "Allow users to send mail notification for shared files" : "Permitir a los usuarios unviar mensaxes de notificación pa ficheros compartíos",
    "Set default expiration date" : "Afitar la data d'espiración predeterminada",
    "Expire after " : "Caduca dempués de",
    "days" : "díes",
    "Enforce expiration date" : "Facer cumplir la data de caducidá",
    "Allow resharing" : "Permitir re-compartición",
    "Restrict users to only share with users in their groups" : "Restrinxir a los usuarios a compartir namái con otros usuarios nos sos grupos",
    "Exclude groups from sharing" : "Esclúi grupos de compartir",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos van poder siguir recibiendo conteníos compartíos, pero nun van poder anicialos",
    "Cron was not executed yet!" : "¡Cron entá nun s'executó!",
    "Execute one task with each page loaded" : "Executar una xera con cada páxina cargada",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php rexístrase nun serviciu webcron pa llamar a cron.php cada 15 minutos al traviés de HTTP.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Usar el serviciu cron del sistema pa llamar al ficheru cron.php cada 15 mins.",
    "This is used for sending out notifications." : "Esto úsase pa unviar notificaciones.",
    "Send mode" : "Mou d'unviu",
    "Encryption" : "Cifráu",
    "From address" : "Dende la direición",
    "mail" : "corréu",
    "Authentication method" : "Métodu d'autenticación",
    "Authentication required" : "Necesítase autenticación",
    "Server address" : "Direición del sirvidor",
    "Port" : "Puertu",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nome d'usuariu SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Test email settings" : "Probar configuración de corréu electrónicu",
    "Send email" : "Unviar mensaxe",
    "More" : "Más",
    "Less" : "Menos",
    "Version" : "Versión",
    "Documentation:" : "Documentación:",
    "Enable only for specific groups" : "Habilitar namái pa grupos específicos",
    "Uninstall App" : "Desinstalar aplicación",
    "Cheers!" : "¡Salú!",
    "Forum" : "Foru",
    "Profile picture" : "Semeya de perfil",
    "Upload new" : "Xubir otra",
    "Remove image" : "Desaniciar imaxe",
    "Cancel" : "Encaboxar",
    "Email" : "Corréu-e",
    "Your email address" : "Direición de corréu-e",
    "Password" : "Contraseña",
    "Unable to change your password" : "Nun pudo camudase la contraseña",
    "Current password" : "Contraseña actual",
    "New password" : "Contraseña nueva",
    "Change password" : "Camudar contraseña",
    "Language" : "Llingua",
    "Help translate" : "Ayúdanos nes traducciones",
    "Get the apps to sync your files" : "Obtener les aplicaciones pa sincronizar ficheros",
    "Desktop client" : "Cliente d'escritoriu",
    "Android app" : "Aplicación d'Android",
    "iOS app" : "Aplicación d'iOS",
    "Show First Run Wizard again" : "Amosar nuevamente l'Encontu d'execución inicial",
    "Username" : "Nome d'usuariu",
    "Create" : "Crear",
    "Admin Recovery Password" : "Recuperación de la contraseña d'alministración",
    "Enter the recovery password in order to recover the users files during password change" : "Introduz la contraseña de recuperación col envís de recuperar los ficheros de los usuarios mientres el cambéu de contraseña.",
    "Add Group" : "Amestar grupu",
    "Group" : "Grupu",
    "Everyone" : "Toos",
    "Admins" : "Almins",
    "Default Quota" : "Cuota predeterminada",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor indica la cuota d'almacenamientu (ex: \"512 MB\" o \"12 GB\")",
    "Unlimited" : "Non llendáu",
    "Other" : "Otru",
    "Full Name" : "Nome completu",
    "Quota" : "Cuota",
    "Storage Location" : "Llocalización d'almacenamientu",
    "Last Login" : "Caberu aniciu de sesión",
    "change full name" : "camudar el nome completu",
    "set new password" : "afitar nueva contraseña",
    "Default" : "Predetermináu"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/ast.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Contraseña incorreuta",
    "No user supplied" : "Nun s'especificó un usuariu",
    "Authentication error" : "Fallu d'autenticación",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Facilita una contraseña de recuperación d'alministrador, sinón podríen perdese tolos datos d'usuariu",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación d'alministrador incorreuta. Comprueba la contraseña ya inténtalo dempués.",
    "Unable to change password" : "Nun pudo camudase la contraseña",
    "Enabled" : "Habilitar",
    "Not enabled" : "Desactiváu",
    "Saved" : "Guardáu",
    "test email settings" : "probar configuración de corréu",
    "Email sent" : "Corréu-e unviáu",
    "You need to set your user email before being able to send test emails." : "Tienes de configurar la direición de corréu-e enantes de poder unviar mensaxes de prueba.",
    "Email saved" : "Corréu-e guardáu",
    "Your full name has been changed." : "Camudóse'l nome completu.",
    "Unable to change full name" : "Nun pue camudase'l nome completu",
    "Sharing" : "Compartiendo",
    "External Storage" : "Almacenamientu esternu",
    "Cron" : "Cron",
    "Log" : "Rexistru",
    "Updates" : "Anovamientos",
    "Couldn't remove app." : "Nun pudo desaniciase l'aplicación.",
    "Language changed" : "Camudóse la llingua",
    "Invalid request" : "Solicitú inválida",
    "Admins can't remove themself from the admin group" : "Los alministradores nun puen desaniciase a ellos mesmos del grupu d'alministrador",
    "Unable to add user to group %s" : "Nun pudo amestase l'usuariu al grupu %s",
    "Unable to remove user from group %s" : "Nun pudo desaniciase al usuariu del grupu %s",
    "Couldn't update app." : "Nun pudo anovase l'aplicación.",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "¿De xuru que quies amestar \"{domain}\" como dominiu de confianza?",
    "Add trusted domain" : "Amestar dominiu de confianza",
    "Sending..." : "Unviando...",
    "All" : "Toos",
    "Please wait...." : "Espera, por favor....",
    "Error while disabling app" : "Fallu mientres se desactivaba l'aplicación",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Error while enabling app" : "Fallu mientres s'activaba l'aplicación",
    "Updating...." : "Anovando....",
    "Error while updating app" : "Fallu mientres s'anovaba l'aplicación",
    "Updated" : "Anováu",
    "Uninstalling ...." : "Desinstalando ...",
    "Error while uninstalling app" : "Fallu mientres se desinstalaba l'aplicación",
    "Uninstall" : "Desinstalar",
    "Valid until {date}" : "Válidu fasta {date}",
    "Delete" : "Desaniciar",
    "Select a profile picture" : "Esbillar una imaxe de perfil",
    "Very weak password" : "Contraseña mui feble",
    "Weak password" : "Contraseña feble",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña bona",
    "Strong password" : "Contraseña mui bona",
    "Groups" : "Grupos",
    "Unable to delete {objName}" : "Nun pue desaniciase {objName}",
    "A valid group name must be provided" : "Hai d'escribir un nome de grupu válidu",
    "deleted {groupName}" : "desaniciáu {groupName}",
    "undo" : "desfacer",
    "no group" : "Ensín grupu",
    "never" : "enxamás",
    "deleted {userName}" : "desaniciáu {userName}",
    "add group" : "amestar Grupu",
    "A valid username must be provided" : "Tien d'apurrise un nome d'usuariu válidu",
    "A valid password must be provided" : "Tien d'apurrise una contraseña válida",
    "__language_name__" : "Asturianu",
    "Unlimited" : "Non llendáu",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Too (Información, Avisos, Fallos, debug y problemes fatales)",
    "Info, warnings, errors and fatal issues" : "Información, Avisos, Fallos y problemes fatales",
    "Warnings, errors and fatal issues" : "Avisos, fallos y problemes fatales",
    "Errors and fatal issues" : "Fallos y problemes fatales",
    "Fatal issues only" : "Namái problemes fatales",
    "None" : "Dengún",
    "Login" : "Entamar sesión",
    "Plain" : "Planu",
    "NT LAN Manager" : "Xestor de NT LAN",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ta aparentemente configuráu pa desaniciar bloques de documentos en llinia. Esto va facer que delles aplicaciones principales nun tean accesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dablemente esto seya culpa d'un caché o acelerador, como por exemplu Zend OPcache o eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Nun s'atopó'l módulu PHP 'fileinfo'. Encamentámoste qu'habilites esti módulu pa obtener meyores resultaos cola deteición de tribes MIME.",
    "System locale can not be set to a one which supports UTF-8." : "Nun se pue escoyer una configuración rexonal que sofite UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Esto significa que pue haber problemes con ciertos caráuteres nos nomes de los ficheros.",
    "Allow apps to use the Share API" : "Permitir a les aplicaciones usar la API de Compartición",
    "Allow users to share via link" : "Permitir a los usuarios compartir vía enllaz",
    "Allow public uploads" : "Permitir xubes públiques",
    "Enforce password protection" : "Ameyora la proteición por contraseña.",
    "Set default expiration date" : "Afitar la data d'espiración predeterminada",
    "Allow users to send mail notification for shared files" : "Permitir a los usuarios unviar mensaxes de notificación pa ficheros compartíos",
    "Expire after " : "Caduca dempués de",
    "days" : "díes",
    "Enforce expiration date" : "Facer cumplir la data de caducidá",
    "Allow resharing" : "Permitir re-compartición",
    "Restrict users to only share with users in their groups" : "Restrinxir a los usuarios a compartir namái con otros usuarios nos sos grupos",
    "Exclude groups from sharing" : "Esclúi grupos de compartir",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos van poder siguir recibiendo conteníos compartíos, pero nun van poder anicialos",
    "Cron was not executed yet!" : "¡Cron entá nun s'executó!",
    "Execute one task with each page loaded" : "Executar una xera con cada páxina cargada",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php rexístrase nun serviciu webcron pa llamar a cron.php cada 15 minutos al traviés de HTTP.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Usar el serviciu cron del sistema pa llamar al ficheru cron.php cada 15 mins.",
    "This is used for sending out notifications." : "Esto úsase pa unviar notificaciones.",
    "Send mode" : "Mou d'unviu",
    "Encryption" : "Cifráu",
    "From address" : "Dende la direición",
    "mail" : "corréu",
    "Authentication method" : "Métodu d'autenticación",
    "Authentication required" : "Necesítase autenticación",
    "Server address" : "Direición del sirvidor",
    "Port" : "Puertu",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nome d'usuariu SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Test email settings" : "Probar configuración de corréu electrónicu",
    "Send email" : "Unviar mensaxe",
    "More" : "Más",
    "Less" : "Menos",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especialmente cuando s'utiliza'l veceru d'escritoriu pa la sincronización de ficheros l'usu de SQLite ta desaconseyáu .",
    "Version" : "Versión",
    "Documentation:" : "Documentación:",
    "Enable only for specific groups" : "Habilitar namái pa grupos específicos",
    "Uninstall App" : "Desinstalar aplicación",
    "Cheers!" : "¡Salú!",
    "Forum" : "Foru",
    "Profile picture" : "Semeya de perfil",
    "Upload new" : "Xubir otra",
    "Remove image" : "Desaniciar imaxe",
    "Cancel" : "Encaboxar",
    "Email" : "Corréu-e",
    "Your email address" : "Direición de corréu-e",
    "Password" : "Contraseña",
    "Unable to change your password" : "Nun pudo camudase la contraseña",
    "Current password" : "Contraseña actual",
    "New password" : "Contraseña nueva",
    "Change password" : "Camudar contraseña",
    "Language" : "Llingua",
    "Help translate" : "Ayúdanos nes traducciones",
    "Name" : "Nome",
    "Username" : "Nome d'usuariu",
    "Get the apps to sync your files" : "Obtener les aplicaciones pa sincronizar ficheros",
    "Desktop client" : "Cliente d'escritoriu",
    "Android app" : "Aplicación d'Android",
    "iOS app" : "Aplicación d'iOS",
    "Show First Run Wizard again" : "Amosar nuevamente l'Encontu d'execución inicial",
    "Create" : "Crear",
    "Admin Recovery Password" : "Recuperación de la contraseña d'alministración",
    "Enter the recovery password in order to recover the users files during password change" : "Introduz la contraseña de recuperación col envís de recuperar los ficheros de los usuarios mientres el cambéu de contraseña.",
    "Add Group" : "Amestar grupu",
    "Group" : "Grupu",
    "Everyone" : "Toos",
    "Admins" : "Almins",
    "Default Quota" : "Cuota predeterminada",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor indica la cuota d'almacenamientu (ex: \"512 MB\" o \"12 GB\")",
    "Other" : "Otru",
    "Full Name" : "Nome completu",
    "Quota" : "Cuota",
    "Storage Location" : "Llocalización d'almacenamientu",
    "Last Login" : "Caberu aniciu de sesión",
    "change full name" : "camudar el nome completu",
    "set new password" : "afitar nueva contraseña",
    "Default" : "Predetermináu"
},
"nplurals=2; plural=(n != 1);");
